@@ -1,15 +1,12 @@
 package Log::Any::Adapter::FileHandle;
-{
-  $Log::Any::Adapter::FileHandle::VERSION = '0.007';
-}
-
+$Log::Any::Adapter::FileHandle::VERSION = '0.009';
 =head1 NAME
 
 Log::Any::Adapter::FileHandle - A basic Log::Any::Adapter to forward messages to a filehandle
 
 =head1 VERSION
 
-version 0.007
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -37,8 +34,9 @@ C<Log::Any> set_adapter method:
 
 =item fh
 
-Pass in your IO::Handle-like object here.  If this isn't specified, it will default to opening STDERR. 
-If the object supports an autoflush method, autoflush will be enabled, unless no_autoflush is set.
+Pass in your IO::Handle-like object here.  If this isn't specified, it will
+default to opening STDERR.  If the object supports an autoflush method,
+autoflush will be enabled, unless no_autoflush is set.
 
 =item no_autoflush
 
@@ -48,15 +46,22 @@ Disable automatically turning on autoflush on the fh object.
 
 A sprintf string that controls the formatting of the message.  It is supplied 2
 arguments: the log level as supplied by Log::Any (usually all-lowercase), and
-the message to be logged.  The default is "[%s] %s\n".  This value should contain the log
-record terminator, such as a newline.
+the message to be logged.  The default is "[%s] %s\n".  This value should
+contain the log record terminator, such as a newline.
+
+=item escape
+
+one of 'none' (default), 'newline', or 'nonascii'.  Controls how messages are
+pre-filtered before passing them to a filehandle. This is handy if you want do
+smoosh messages into a single line (for easier filtering + processing), or if
+you want to filter non ascii characters for safe terminal printing.
 
 =back
 
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2010 by Jason Jay Rodrigues <jasonjayr+oss@gmail.com>
+Copyright 2014 by Jason Jay Rodrigues <jasonjayr+oss@gmail.com>
 
 Log::Any::Adapter::FileHandle is provided "as is" and without any express or
 implied warranties, including, without limitation, the implied warranties of
@@ -78,7 +83,6 @@ use base qw(Log::Any::Adapter::Base);
 sub init {
 	my ($self, %attr) = @_;
 	
-	
 	# if no fh object is set, we default to STDERR.
 	if(!exists($self->{fh})) { 
 		$self->{fh} = IO::Handle->new_from_fd(fileno(STDERR),'w');
@@ -92,6 +96,10 @@ sub init {
 	if(!exists($self->{format})) { 
 		$self->{format} = "[%s] %s\n";
 	}
+
+	if(!exists($self->{escape})) { 
+		$self->{escape} = 'none';
+	}
 }
 
 
@@ -100,8 +108,16 @@ sub init {
 	foreach my $method ( Log::Any->logging_methods() ) {
 		my $logger = sub {
 			my $self = shift;
+			my $message = join('',@_);
+			if($self->{escape} eq 'newline' || $self->{escape} eq 'nonascii') { 
+				$message =~ s/\n/\\n/sg;
+				$message =~ s/\r/\\r/sg;
+			}
+			if($self->{escape} eq 'nonascii') { 
+				$message =~ s/(\P{ASCII}|\p{PosixCntrl})/sprintf("\\x{%x}",ord($1))/eg;
+			}
 			if($self->{fh}) { 
-				$self->{fh}->print(sprintf($self->{format}, $method, join('',@_)));
+				$self->{fh}->print(sprintf($self->{format}, $method, $message));
 			}
 		};
 		make_method($method, $logger);
